@@ -20,27 +20,27 @@
  */
 
 #include <krandomsequence.h>
-#include <kapplication.h>
-#include <kglobalsettings.h>
+#include <tdeapplication.h>
+#include <tdeglobalsettings.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <kmimetype.h>
 #include <kstandarddirs.h>
-#include <kmessagebox.h>
-#include <kio/netaccess.h>
-#include <kio/job.h>
+#include <tdemessagebox.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/job.h>
 #include <kprogress.h>
-#include <kfilemetainfo.h>
+#include <tdefilemetainfo.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kpushbutton.h>
 #include <kdebug.h>
 #include <kurl.h>
-#include <kaccel.h>
+#include <tdeaccel.h>
 #include <dcopref.h>
-#include <ktoolbar.h>
+#include <tdetoolbar.h>
 #include <kcolordialog.h>
 #include <kurlcombobox.h>
 #include <kurlcompletion.h>
@@ -219,7 +219,7 @@ void CoverFrame::setCoverPixmap( const TQString &path )
 void CoverFrame::popup( const TQPixmap &pix ) const
 {
     TQPoint mouse  = TQCursor::pos();
-    TQRect desktop = KApplication::desktop()->screenGeometry(mouse);
+    TQRect desktop = TDEApplication::desktop()->screenGeometry(mouse);
     int x = mouse.x();
     int y = mouse.y();
     int height = pix.height() + 4;
@@ -294,7 +294,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	vSplit = new TQSplitter( Qt::Vertical, panel );
 	vSplit->setOpaqueResize( true );
 	TQWidget *vb = new TQWidget( vSplit );
-	KToolBar *tb = new KToolBar( vb );
+	TDEToolBar *tb = new TDEToolBar( vb );
 	TQVBoxLayout *v = new TQVBoxLayout( vb, 0, 0 );
 	v->addWidget( tb );
 	tb->setIconSize( 16 );
@@ -319,12 +319,12 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	view->setSelectionMode( KFile::Multi );
 	fileBrowser->setMode( KFile::Files );
 	fileBrowser->setView( view );
-	fileBrowser->setViewConfig( KGlobal::config(), "PlaylistFileBrowser" );
+	fileBrowser->setViewConfig( TDEGlobal::config(), "PlaylistFileBrowser" );
 	fileBrowser->setOnlyDoubleClickSelectsFiles( true );
 	v1->addWidget( fileBrowser );
 	v->addLayout( v1 );
 
-	KActionCollection *col = fileBrowser->actionCollection();
+	TDEActionCollection *col = fileBrowser->actionCollection();
 	col->action( "up" )->plug( tb );
 	col->action( "back" )->plug( tb );
 	col->action( "forward" )->plug( tb );
@@ -339,14 +339,14 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 
 	m_playlistDirectory = locateLocal("appdata", "playlists");
 	m_playlistDirectory.append("/");
-	KIO::NetAccess::mkdir(m_playlistDirectory, mainWidget);
+	TDEIO::NetAccess::mkdir(m_playlistDirectory, mainWidget);
 	kdDebug() << "PLAYLIST" << endl;
 
 	TQGridLayout* layout = new TQGridLayout( playlist, 4, 2, 3 );
 
 	m_list = new UrlListView(playlist);
 	mainWidget->setAcceptDrops(true);
-	m_list->setHScrollBarMode(KListView::AlwaysOff);
+	m_list->setHScrollBarMode(TDEListView::AlwaysOff);
 	m_list->setItemMargin(2);
 	m_list->setMargin(0);
 	m_list->setSelectionMode(TQListView::Extended);
@@ -364,7 +364,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	m_list->setColumnWidthMode(TRACK_COLUMN, TQListView::Manual);
 	m_list->setColumnWidthMode(LENGTH_COLUMN, TQListView::Manual);
 	m_list->setResizeMode(TQListView::NoColumn);
-	KConfig* config = kapp->config();
+	TDEConfig* config = kapp->config();
 	m_list->restoreLayout(config, "Playlist Layout");
 	m_list->setFullWidth(true);
 	m_list->setSorting(-1);
@@ -390,7 +390,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	searchBtn = new TQToolButton( playlist );
 	searchBtn->setAutoRaise( true );
 	TQToolTip::add( searchBtn, i18n("Search"));
-	searchBtn->setIconSet( KGlobal::iconLoader()->loadIconSet("locationbar_erase", KIcon::Small) );
+	searchBtn->setIconSet( TDEGlobal::iconLoader()->loadIconSet("locationbar_erase", TDEIcon::Small) );
 	h1->addWidget( searchBtn );
 	TQLabel* filterLabel = new TQLabel(i18n("Filter") + ":", playlist);
 	h1->addWidget(filterLabel);
@@ -415,11 +415,11 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	roller = new RollTitle( playlist );
 	layout->addWidget( roller, 0, 1 );
 
-	KAccel* accel = new KAccel(mainWidget);
+	TDEAccel* accel = new TDEAccel(mainWidget);
 	accel->insert("Delete selected", TQt::Key_Delete, this, TQT_SLOT(slotRemoveSelected()));
 
 	m_isCurrentEntry = UserIcon("playing");
-	m_cdPixmap = KGlobal::iconLoader()->loadIcon("cdtrack", KIcon::Small);
+	m_cdPixmap = TDEGlobal::iconLoader()->loadIcon("application-x-cda", TDEIcon::Small);
 
 	setXMLFile("kaffeineplaylist.rc");
 	setupActions();
@@ -433,7 +433,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 		}
 	}
 
-	loadConfig( KGlobal::config() );
+	loadConfig( TDEGlobal::config() );
 
 	connect(coverFrame, TQT_SIGNAL(changeCurrentCover()), this, TQT_SLOT(chooseCurrentCover()));
 	connect(coverFrame, TQT_SIGNAL(gallery()), this, TQT_SLOT(showGallery()));
@@ -497,19 +497,19 @@ PlayList::~PlayList()
 
 void PlayList::setupActions()
 {
-	m_repeat = new KToggleAction(i18n("&Repeat"), 0 , CTRL|Key_E, this, TQT_SLOT(slotRepeat()), actionCollection(),"playlist_repeat");
+	m_repeat = new TDEToggleAction(i18n("&Repeat"), 0 , CTRL|Key_E, this, TQT_SLOT(slotRepeat()), actionCollection(),"playlist_repeat");
 	m_repeat->setStatusText(i18n("Loop playlist"));
-	m_shuffle = new KToggleAction(i18n("Sh&uffle"), 0 , CTRL|Key_R, this, TQT_SLOT(slotShuffle()), actionCollection(),"playlist_shuffle");
+	m_shuffle = new TDEToggleAction(i18n("Sh&uffle"), 0 , CTRL|Key_R, this, TQT_SLOT(slotShuffle()), actionCollection(),"playlist_shuffle");
 	m_shuffle->setStatusText(i18n("Play items in random order"));
-	m_autoCover = new KToggleAction(i18n("Autodownload covers"), 0 , 0, this, TQT_SLOT(slotAutoCover()), actionCollection(),"playlist_autocover");
+	m_autoCover = new TDEToggleAction(i18n("Autodownload covers"), 0 , 0, this, TQT_SLOT(slotAutoCover()), actionCollection(),"playlist_autocover");
 	m_autoCover->setStatusText(i18n("Automatic dowloading of covers"));
-	m_showPlayer = new KToggleAction(i18n("Don't switch to player window"), 0 , 0, this, TQT_SLOT(slotShowPlayer()), actionCollection(),"playlist_showplayer");
+	m_showPlayer = new TDEToggleAction(i18n("Don't switch to player window"), 0 , 0, this, TQT_SLOT(slotShowPlayer()), actionCollection(),"playlist_showplayer");
 	m_showPlayer->setStatusText(i18n("Don't switch automatically to player window"));
-	new KAction(i18n("&Clear Current Playlist"), "eraser", 0, this, TQT_SLOT(slotClearList()), actionCollection(), "playlist_clear");
-	new KAction(i18n("Ne&w Playlist"), "filenew", 0, this, TQT_SLOT(slotNewList()), actionCollection(), "playlist_new");
-	new KAction(i18n("&Import Playlist..."), "project_open", 0, this, TQT_SLOT(slotPlaylistLoad()), actionCollection(), "playlist_load");
-	new KAction(i18n("&Save Current Playlist As..."), "filesaveas", 0, this, TQT_SLOT(slotPlaylistSaveAs()), actionCollection(), "playlist_save_as");
-	new KAction(i18n("Re&move Current Playlist"), "fileclose", 0, this, TQT_SLOT(slotPlaylistRemove()), actionCollection(), "playlist_remove");
+	new TDEAction(i18n("&Clear Current Playlist"), "eraser", 0, this, TQT_SLOT(slotClearList()), actionCollection(), "playlist_clear");
+	new TDEAction(i18n("Ne&w Playlist"), "document-new", 0, this, TQT_SLOT(slotNewList()), actionCollection(), "playlist_new");
+	new TDEAction(i18n("&Import Playlist..."), "project_open", 0, this, TQT_SLOT(slotPlaylistLoad()), actionCollection(), "playlist_load");
+	new TDEAction(i18n("&Save Current Playlist As..."), "document-save-as", 0, this, TQT_SLOT(slotPlaylistSaveAs()), actionCollection(), "playlist_save_as");
+	new TDEAction(i18n("Re&move Current Playlist"), "window-close", 0, this, TQT_SLOT(slotPlaylistRemove()), actionCollection(), "playlist_remove");
 }
 
 void PlayList::slotClearList()
@@ -590,7 +590,7 @@ TQWidget* PlayList::inputMainWidget()
 	return mainWidget;
 }
 
-void PlayList::loadConfig(KConfig* config)
+void PlayList::loadConfig(TDEConfig* config)
 {
 	TQValueList<int> sl;
 	bool b;
@@ -646,10 +646,10 @@ void PlayList::loadConfig(KConfig* config)
 
 void PlayList::saveConfig()
 {
-	saveConfig( KGlobal::config() );
+	saveConfig( TDEGlobal::config() );
 }
 
-void PlayList::saveConfig(KConfig* config)
+void PlayList::saveConfig(TDEConfig* config)
 {
 	saveCurrentPlaylist();
 	config->setGroup("Playlist");
@@ -935,13 +935,13 @@ TQListViewItem* PlayList::insertItem(TQListViewItem* after, const MRL& m)
 		mrl.setMime(mime->name());
 	}
 
-	tmp = new PlaylistItem(m_list, dynamic_cast<KListViewItem *>(after), mrl);
+	tmp = new PlaylistItem(m_list, dynamic_cast<TDEListViewItem *>(after), mrl);
 	if (!tmp) return after;
 
 	if ((mrl.mime() == "video/dvd") || (mrl.mime() == "video/vcd") || (mrl.mime() == "audio/cd"))
 		tmp->setPixmap(MIME_COLUMN, m_cdPixmap);
 	else
-		tmp->setPixmap(MIME_COLUMN, KMimeType::mimeType(mrl.mime())->pixmap(KIcon::Small));
+		tmp->setPixmap(MIME_COLUMN, KMimeType::mimeType(mrl.mime())->pixmap(TDEIcon::Small));
 
 	if (tmp->length().contains(':'))
 		m_playTime += timeStringToMs(tmp->length());
@@ -1344,7 +1344,7 @@ void PlayList::add(const TQStringList& urlList, TQListViewItem* after)
 			break;
 		progress->progressBar()->setProgress(i+1);
 		progress->setLabel(TQString::number(i+1) + " / " + TQString::number(progress->progressBar()->totalSteps()) + " " + i18n("Files"));
-		KApplication::kApplication()->processEvents();
+		TDEApplication::kApplication()->processEvents();
 	}
 
 	delete progress;
@@ -1403,7 +1403,7 @@ void PlayList::createRandomList()
 		return;
 	}
 
-	KRandomSequence r(KApplication::random());
+	KRandomSequence r(TDEApplication::random());
 	r.randomize(&m_randomList);
 }
 
@@ -1710,7 +1710,7 @@ void PlayList::setCover( TQString s1, TQString s2, bool forceFetch )
 			TQString path = locate("appdata", "nocover.png");
 			if ( !path )
 				path = locate("data", "kaffeine/nocover.png");
-			KIO::file_copy( KURL::fromPathOrURL( path ), KURL::fromPathOrURL( fname ), -1, true );
+			TDEIO::file_copy( KURL::fromPathOrURL( path ), KURL::fromPathOrURL( fname ), -1, true );
 		}
 	}
 }
@@ -1862,8 +1862,8 @@ void PlayList::slotNewPlaylistName(const TQString& text)
 	}
 	TQString oldPl = m_playlistDirectory + m_playlistSelector->text(m_currentPlaylist) + ".kaffeine";
 	kdDebug() << "Playlist: removing file: " << oldPl << endl;
-	if (!KIO::NetAccess::del(oldPl, mainWidget))
-		kdError() << "Playlist: " << KIO::NetAccess::lastErrorString() << endl;
+	if (!TDEIO::NetAccess::del(oldPl, mainWidget))
+		kdError() << "Playlist: " << TDEIO::NetAccess::lastErrorString() << endl;
 
 	kdDebug() << "PlayList: Set playlist name to: " << text << endl;
 	m_playlistSelector->changeItem(text, m_currentPlaylist);
@@ -1890,8 +1890,8 @@ void PlayList::removeCurrentPlaylist()
 	if (code == KMessageBox::Continue)
 	{
 		TQString pl = m_playlistDirectory + m_playlistSelector->text(m_currentPlaylist) + ".kaffeine";
-		if (!KIO::NetAccess::del(pl, mainWidget))
-			kdError() << "Playlist: " << KIO::NetAccess::lastErrorString() << endl;
+		if (!TDEIO::NetAccess::del(pl, mainWidget))
+			kdError() << "Playlist: " << TDEIO::NetAccess::lastErrorString() << endl;
 
 		m_playlistSelector->removeItem(m_currentPlaylist);
 		m_currentPlaylist = m_playlistSelector->currentItem();
