@@ -41,9 +41,9 @@
 #include <tqdir.h>
 #include <tqprogressdialog.h>
 
-#include <klocale.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdemessagebox.h>
 
 #include "dvbstream.h"
 #include "dvbevents.h"
@@ -1029,7 +1029,7 @@ bool DvbStream::running() const
 
 void DvbStream::receivePlayDvb()
 {
-	KApplication::kApplication()->postEvent( this, new TQTimerEvent( 500 ) );
+	TDEApplication::kApplication()->postEvent( this, new TQTimerEvent( 500 ) );
 }
 
 
